summaryrefslogtreecommitdiffstats
path: root/tools/designer/uilib/qwidgetfactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/designer/uilib/qwidgetfactory.cpp')
-rw-r--r--tools/designer/uilib/qwidgetfactory.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/designer/uilib/qwidgetfactory.cpp b/tools/designer/uilib/qwidgetfactory.cpp
index 269f6c355..cbf49cc47 100644
--- a/tools/designer/uilib/qwidgetfactory.cpp
+++ b/tools/designer/uilib/qwidgetfactory.cpp
@@ -174,7 +174,7 @@ static TQImage loadImageData( const TQString& format, ulong len, TQByteArray dat
if ( format == "XPM.GZ" || format == "XBM.GZ" ) {
if ( len < data.size() * 10 )
len = data.size() * 10;
// qUncompress() expects the first 4 bytes to be the expected length of
// the uncompressed data
TQByteArray dataTmp( data.size() + 4 );
memcpy( dataTmp.data()+4, data.data(), data.size() );
@@ -182,7 +182,7 @@ static TQImage loadImageData( const TQString& format, ulong len, TQByteArray dat
dataTmp[1] = ( len & 0x00ff0000 ) >> 16;
dataTmp[2] = ( len & 0x0000ff00 ) >> 8;
dataTmp[3] = ( len & 0x000000ff );
- TQByteArray baunzip = qUncompress( dataTmp );
+ TQByteArray baunzip = tqUncompress( dataTmp );
len = baunzip.size();
img.loadFromData( (const uchar*)baunzip.data(), len, format.left(format.find('.')) );
} else {
@@ -491,7 +491,7 @@ TQWidget *TQWidgetFactory::createFromUiFile( TQDomDocument doc, TQObject *connec
if ( !connections.isNull() )
loadConnections( connections, connector );
- if ( w && name && qstrlen( name ) > 0 )
+ if ( w && name && tqstrlen( name ) > 0 )
w->setName( name );
if ( !tabOrder.isNull() )
@@ -174,7 +174,7 @@ static TQImage loadImageData( const TQString& format, ulong len, TQByteArray dat
if ( len < data.size() * 10 )
len = data.size() * 10;
- // qUncompress() expects the first 4 bytes to be the expected length of
+ // tqUncompress() expects the first 4 bytes to be the expected length of
// the uncompressed data
TQByteArray dataTmp( data.size() + 4 );